package Travel::Status::DE::DBRIS::Operators;

# vim:readonly
# This module has been automatically generated from share/admin-id-to-operator.json
# by lib/Travel/Status/DE/DBRIS/Operators.pm.PL.
# Do not edit, changes will be lost.

use strict;
use warnings;
use 5.020;
use utf8;

our $VERSION = '0.21';

# Automatically generated, see share/stations.json
my %admin_id_to_operator = (
'NXRE' => ['RE', 'National Express'],
'800456' => ['DB', 'DB Regio AG Südost'],
'800631' => ['DB', 'DB Regio AG Baden-Württemberg'],
'8004OB' => ['OBS', 'DB RegioNetz Verkehrs GmbH Oberweißbacher Berg+Schwarzatalbahn'],
'NXRB' => ['RB', 'National Express'],
'850038' => ['ASM', 'Aare Seeland mobil'],
'ABRE' => ['RE', 'SWEG Bahn Stuttgart GmbH'],
'vrn011' => ['STR', 'Rhein-Neckar-Verkehr GmbH'],
'pbaKB' => ['ÖPO', 'ÖBB-Postbus'],
'800279' => ['DB', 'DB Regio AG Nord'],
'800157' => ['DB', 'DB Regio AG Nordost'],
'810028' => ['GyS', 'GySEV'],
'800640' => ['SWX', 'DB Regio AG Mitte SÜWEX'],
'ABRB' => ['RB', 'SWEG Bahn Stuttgart GmbH'],
'800430' => ['EGB', 'DB RegioNetz Verkehrs GmbH Erzgebirgsbahn'],
'850097' => ['TRA', 'Transports Vallée de Joux-Yverdon-Ste-Croix'],
'861002' => ['DSB', 'Dänische Staatsbahnen'],
'H6' => ['HzL', 'Hohenzollerische Landesbahn (SWEG)'],
'NX' => ['NX', 'National Express'],
'rvoRVO' => ['RVO', 'Regionalverkehr Oberbayern'],
'SBSIRE' => ['IRE', 'SWEG Bahn Stuttgart GmbH'],
'A6S52' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'801591' => ['DB', 'DB Regio AG Mitte'],
'51PR-S' => ['PR', 'Polregio'],
'rbgSBG' => ['SBG', 'Südbadenbus'],
'3246' => ['IC', 'RegioJet'],
'800292' => ['DB', 'DB Regio AG Nord'],
'NBRB12' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'AB' => ['ABR', 'SWEG Bahn Stuttgart GmbH'],
'NBRB60' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'800363' => ['DB', 'DB Regio AG NRW'],
'840055' => ['BN', 'Blauwnet'],
'800759' => ['DB', 'DB Regio AG Bayern'],
'K6' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'OWRB15' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'OWRB46' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'A6S4' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'840500' => ['ARR', 'Arriva Nederland'],
'SD' => ['DB', 'DB Regio AG Südost'],
'NBRB63' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'OWRB51' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'A6S7' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'850022' => ['AB', 'Appenzeller Bahnen'],
'B4' => ['S', 'DB Regio AG S-Bahn Rhein-Main'],
'800338' => ['DB', 'DB Regio AG NRW'],
'V6RE' => ['RE', 'vlexx'],
'800725' => ['S', 'DB Regio AG S-Bahn München'],
'V6RB' => ['RB', 'vlexx'],
'OWRB33' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'L8' => ['BRB', 'Bayerische Regiobahn'],
'800271' => ['DB', 'DB Regio AG Nord'],
'N6' => ['SWE', 'Südwestdeutsche Landesverkehrs-GmbH'],
'8003L2' => ['DB', 'DB Regio AG NRW'],
'857221' => ['THU', 'THURBO'],
'800643' => ['S', 'DB Regio AG S-Bahn Stuttgart'],
'800417' => ['DB', 'DB Regio AG Südost'],
'UW' => ['UBB', 'Usedomer Bäderbahn'],
'A6S51' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'V6' => ['vlx', 'vlexx'],
'Z8' => ['BZB', 'Bayerische Zugspitzbahn'],
'800155' => ['DB', 'DB Regio AG Nordost'],
'85' => ['SBB', 'SBB'],
'51PR-Q' => ['PR', 'Polregio'],
'800746' => ['DB', 'DB Regio AG Bayern'],
'FLX10' => ['FLX', 'FlixTrain'],
'801599' => ['DB', 'DB Regio AG Mitte'],
'859999' => ['SBB', 'SBB'],
'8006D2' => ['DB', 'DB Regio AG Baden-Württemberg'],
'800553' => ['DB', 'DB Regio AG Mitte'],
'E0' => ['EVB', 'EVB ELBE-WESER GmbH'],
'79' => ['SZ', 'Slovenske zeleznice'],
'M2RE' => ['R', 'REGIOBAHN'],
'840100' => ['NS', 'Nederlandse Spoorwegen'],
'850371' => ['BC', 'Société coopérative du Chemin de fer - Musée Blonay-Chamby'],
'C6' => ['KTB', 'Kandertalbahn'],
'OD' => ['SOE', 'Sächsisch-Oberlausitzer Eisenbahngesellschaft'],
'vgsSBS' => ['S', 'Saarbahn'],
'850093' => ['MGB', 'Matterhorn Gotthard Bahn (bvz)'],
'rabRAB' => ['RAB', 'Regionalverkehr Alb-Bodensee'],
'81' => ['ÖBB', 'Österreichische Bundesbahnen'],
'3332' => ['KZC', 'KZC Doprava s.r.o.'],
'N0' => ['neg', 'Norddeutsche Eisenbahn Gesellschaft'],
'BW' => ['DB', 'DB Regio AG Nordost'],
'857231' => ['SBB', 'SBB'],
'OWRB64' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'SBSRB' => ['RB', 'SWEG Bahn Stuttgart GmbH'],
'M2' => ['S', 'REGIOBAHN'],
'owl031' => ['STB', 'moBiel GmbH'],
'801566' => ['DB', 'DB Regio AG Mitte'],
'L7' => ['SBB', 'SBB GmbH'],
'850065' => ['THU', 'THURBO'],
'vrnRHB' => ['RNV', 'Rhein-Neckar-Verkehr GmbH (Rhein-Haardtbahn)'],
'NYUEX' => ['UEX', 'Urlaubs-Express'],
'A6S11' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'810024' => ['P', 'Waldviertler Schmalspurbahn'],
'8002A3' => ['DB', 'DB Regio AG Nord'],
'800153' => ['DB', 'DB Regio AG Nordost'],
'SBSRE' => ['RE', 'SWEG Bahn Stuttgart GmbH'],
'A6S81' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'V9' => ['P', 'Wanderbahn im Regental'],
'850032' => ['BLM', 'Lauterbrunnen-Mürren'],
'TDHS' => ['S', 'S-Bahn Hannover (Transdev)'],
'800413' => ['DB', 'DB Regio AG Südost'],
'800647' => ['DB', 'DB Regio AG Baden-Württemberg'],
'EX' => ['RE', 'Erfurter Bahn GmbH'],
'8006D8' => ['DB', 'DB Regio AG Baden-Württemberg'],
'CX' => ['MRB', 'Mitteldeutsche Regiobahn'],
'8005SV' => ['DB', 'Rhein-Mosel-Bus Ahrweiler'],
'800489' => ['DB', 'DB Regio AG Südost'],
'rbpRMA' => ['DB', 'Rhein-Mosel-Bus Ahrweiler'],
'853271' => ['ANA', 'Association neuchâteloise des Amis du Tramway ANAT'],
'810008' => ['STH', 'Stern & Hafferl Verkehrs-GmbH'],
'TRI' => ['TRI', 'TRI Train Rental GmbH'],
'N2' => ['NWB', 'NordWestBahn'],
'ak_AK' => ['AK', 'Autokraft'],
'GYRE' => ['RE', 'Go-Ahead Bayern GmbH'],
'BB' => ['DB', 'DB Regio AG Nordost'],
'857206' => ['SBB', 'SBB'],
'GYRB' => ['RB', 'Go-Ahead Bayern GmbH'],
'M9' => ['MSB', 'Mainschleifenbahn'],
'rbgRVs' => ['RVS', 'Südwestbus'],
'vrn050' => ['QNV', 'QNV Queichtal Nahverkehr'],
'CXRB' => ['RB', 'Mitteldeutsche Regiobahn'],
'800720' => ['DB', 'DB Regio AG Bayern'],
'A6S12' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'CXRE' => ['RE', 'Mitteldeutsche Regiobahn'],
'FLX11' => ['FLX', 'FlixTrain'],
'GY' => ['GA', 'Go-Ahead Bayern GmbH'],
'OWRB13' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'HL' => ['HSB', 'Harzer Schmalspurbahn'],
'800318' => ['DB', 'DB Arriva'],
'8006000' => ['DB', 'DB Regio AG Baden-Württemberg'],
'800486' => ['DB', 'DB Regio AG Südost'],
'Y0' => ['SCH', 'Adler-Schiffe'],
'R4NRN' => ['VIA', 'VIAS Rail GmbH'],
'SB' => ['RB', 'Süd-Thüringen-Bahn GmbH'],
'810043' => ['ÖPO', 'ÖBB-Postbus'],
'800693' => ['DB', 'DB Regio AG Baden-Württemberg'],
'800772' => ['DB', 'DB Regio AG Bayern'],
'88' => ['SCB', 'SNCB'],
'FLX30' => ['FLX', 'FlixTrain'],
'vrn008' => ['STR', 'Rhein-Neckar-Verkehr GmbH'],
'R4RH' => ['VIA', 'VIAS GmbH'],
'8013E' => ['SOB', 'DB RegioNetz Verkehrs GmbH Südostbayernbahn'],
'800528' => ['S', 'DB Regio AG S-Bahn Rhein-Main'],
'AMS' => ['S', 'Abellio Rail Mitteldeutschland GmbH'],
'810009' => ['WiL', 'Wiener Linien'],
'84' => ['NS', 'Nederlandse Spoorwegen'],
'rbgAST' => ['SBG', 'Südbadenbus'],
'vrr088' => ['BVR', 'Busverkehr Rheinland'],
'85DBSH' => ['SBB', 'SBB'],
'NBRB26' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'8005ND' => ['DB', 'DB Regio AG Mitte'],
'TDRR' => ['RRB', 'RheinRuhrBahn (Transdev)'],
'800632' => ['DB', 'DB Regio AG Baden-Württemberg'],
'B5' => ['DB', 'DB Regio AG Mitte'],
'850029' => ['MBC', 'Transports de la région Morges-Bière-Cossonay'],
'800160' => ['DB', 'DB Regio AG Nordost'],
'800742' => ['DB', 'DB Regio AG Bayern'],
'8006D6' => ['DB', 'DB Regio AG Baden-Württemberg'],
'RSTN' => ['STN', 'Regionalverkehre Start Deutschland GmbH (Start Taunus)'],
'8006D1' => ['DB', 'DB Regio AG Baden-Württemberg'],
'800163' => ['DB', 'DB Regio AG Nordost'],
'NWBus' => ['NWB', 'NordWestBahn'],
'850047' => ['FLP', 'Lugano-Ponte Tresa'],
'8003L1' => ['DB', 'DB Regio AG NRW'],
'850055' => ['LEB', 'Lausanne-Echallens-Bercher'],
'tgo099' => ['SWE', 'SWEG Südwestdeutsche Landesverkehrs-GmbH'],
'OWRE4' => ['RE', 'Ostdeutsche Eisenbahn GmbH'],
'3230' => ['VBG', 'vogtlandbahn - Die Länderbahn GmbH DLB'],
'810031' => ['STR', 'Linz Linien AG (Straßenbahn Stadt Linz)'],
'vrn022' => ['MNV', 'MNV Mittelhaardt Nahverkehrsgesellschaft'],
'E3' => ['P', 'Kasbachtalbahn'],
'GAIRE' => ['IRE', 'Go-Ahead Baden-Württemberg GmbH'],
'8005KG' => ['DB', 'DB Regio AG Mitte'],
'vrn032' => ['PAL', 'PalatinaBus'],
'850031' => ['BDW', 'BDWM Transport'],
'8003RL' => ['DB', 'DB Regio AG NRW'],
'800165' => ['DB', 'DB Regio AG Nordost'],
'LD' => ['TL', 'trilex - Die Länderbahn GmbH DLB'],
'TR' => ['RB', 'MittelrheinBahn (Trans Regio)'],
'rbgRBS' => ['RBS', 'Regiobus Stuttgart'],
'webBTR' => ['STR', 'Bremer Straßenbahn AG'],
'850053' => ['TPF', 'Transports publics fribourgeois'],
'801513' => ['DB', 'DB Regio AG Mitte'],
'810021' => ['NÖV', 'NÖ Verkehrsorganisations-ges.m.b.H.'],
'56' => ['ZSS', 'ZSSK'],
'A6S32' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'BD' => ['SDG', 'SDG Sächsische Dampfeisenbahngesellschaft mbH'],
'O7' => ['ÖBA', 'Öchsle-Bahn-Betriebsgesellschaft mbH'],
'OWRE' => ['RE', 'Ostdeutsche Eisenbahn GmbH'],
'8007DU' => ['DB', 'DB Regio AG Bayern'],
'SBX' => ['RE', 'Süd-Thüringen-Bahn GmbH'],
'OWRB' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'ak_DRN' => ['DIB', 'Dithmarschenbus (DB Regio Bus Nord GmbH)'],
'800478' => ['DB', 'DB Regio AG Südost'],
'850846' => ['RVS', 'Regionale Verkehrsbetriebe Schaffhausen'],
'R4S7' => ['VIA', 'VIAS Rail GmbH'],
'NZ' => ['RE', 'DB Fernverkehr AG'],
'R0' => ['ENO', 'enno'],
'vrn028' => ['H&P', 'Hetzler & Pfadt'],
'webYGO' => ['RBB', 'Regionalbus Braunschweig GmbH'],
'A6S31' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'800622' => ['DB', 'DB Regio AG Baden-Württemberg'],
'800469' => ['DB', 'DB Regio AG Südost'],
'810011' => ['R', 'Schneebergbahn'],
'0S' => ['S', 'S-Bahn Hamburg'],
'8006C5' => ['DB', 'DB Regio AG Baden-Württemberg'],
'B1' => ['DB', 'DB Regio AG Nord'],
'R2RB' => ['RB', 'eurobahn'],
'R2RE' => ['RE', 'eurobahn'],
'850073' => ['TRN', 'Transports Publics Neuchâtelois SA'],
'A5' => ['VEN', 'Rhenus Veniro'],
'X1' => ['erx', 'erixx'],
'NBRB36' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'850043' => ['CJ', 'Chemins de fer du Jura'],
'8007D5' => ['DB', 'DB Regio AG Bayern'],
'R4WEST' => ['VIA', 'VIAS Rail GmbH'],
'8005A4' => ['DB', 'DB Regio AG Mitte'],
'SBSMEX' => ['MEX', 'SWEG Bahn Stuttgart GmbH'],
'87' => ['SCF', 'SNCF'],
'51KD' => ['KD', 'Koleje Dolnoslaskie'],
'R2' => ['ERB', 'eurobahn'],
'800333' => ['DB', 'DB Regio AG NRW'],
'R4' => ['VIA', 'VIAS Rail GmbH'],
'AM' => ['ABR', 'Abellio Rail Mitteldeutschland GmbH'],
'OWRB14' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'CD' => ['CB', 'City-Bahn Chemnitz'],
'ED' => ['FEG', 'Freiberger Eisenbahngesellschaft'],
'S9' => ['ag', 'agilis'],
'3236' => ['WB', 'WESTbahn'],
'840054' => ['Vll', 'Valleilijn'],
'OWRE2' => ['RE', 'Ostdeutsche Eisenbahn GmbH'],
'840052' => ['Brg', 'Breng'],
'RS' => ['RE', 'Regionalverkehre Start Deutschland GmbH'],
'3393' => ['TGV', 'SNCF Voyages Deutschland'],
'800351' => ['DB', 'DB Regio AG NRW'],
'800295' => ['DB', 'DB Regio AG Nord'],
'AMRE' => ['RE', 'Abellio Rail Mitteldeutschland GmbH'],
'8015A6' => ['DB', 'DB Regio AG Mitte'],
'webUET' => ['STB', 'üstra Hannoversche Verkehrsbetriebe AG'],
'NBRB27' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'SAD003' => ['SAD', 'Vinschgaubahn'],
'AMRB' => ['RB', 'Abellio Rail Mitteldeutschland GmbH'],
'810007' => ['SLB', 'Salzburger Lokalbahnen'],
'800349' => ['DB', 'DB Regio AG NRW'],
'550043' => ['GyS', 'GySEV'],
'800714' => ['DB', 'DB Regio AG Bayern'],
'850056' => ['ASM', 'Aare Seeland mobil'],
'3018' => ['THA', 'THALYS'],
'NBRB25' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'800154' => ['DB', 'DB Regio AG Nordost'],
'850046' => ['FB', 'Forchbahn'],
'850801' => ['PAG', 'PostAuto Schweiz'],
'810023' => ['NÖV', 'NÖ Verkehrsorganisations-ges.m.b.H.'],
'810005' => ['ZB', 'Zillertalbahn'],
'80SEV' => ['DB', 'DB Fernverkehr AG'],
'850051' => ['FW', 'Frauenfeld-Wil'],
'rbgRVS' => ['RVS', 'Südwestbus'],
'T8' => ['BRB', 'Bayerische Regiobahn'],
'RSUE' => ['RE', 'Regionalverkehre Start Deutschland GmbH (Start Unterelbe)'],
'86' => ['DSB', 'Dänische Staatsbahnen'],
'19' => ['EST', 'EUROSTAR'],
'850033' => ['BLS', 'BLS AG'],
'8003G1' => ['DB', 'DB Regio AG NRW'],
'8015A1' => ['DB', 'DB Regio AG Mitte'],
'O9X' => ['OPX', 'oberpfalz-express - Die Länderbahn GmbH DLB'],
'801526' => ['DB', 'DB Regio AG Mitte'],
'8003A5' => ['DB', 'DB Regio AG NRW'],
'W6' => ['WTB', 'Wutachtalbahn'],
'850049' => ['FAR', 'Ferrovie Autolinee Regionali Ticinesi'],
'810003' => ['mbs', 'Montafoner Bahn'],
'810025' => ['SLB', 'Salzburger Lokalbahnen'],
'GA' => ['GA', 'Go-Ahead Baden-Württemberg GmbH'],
'AMHBX' => ['HBX', 'Abellio Rail Mitteldeutschland GmbH'],
'71' => ['REN', 'RENFE'],
'W0' => ['WDR', 'Wyker Dampfschiffs-Reederei Föhr-Amrum GmbH'],
'swg099' => ['SWE', 'SWEG Südwestdeutsche Landesverkehrs-GmbH'],
'RC' => ['AZS', 'AUTOZUG Sylt'],
'ak_SVG' => ['SVG', 'Sylter Verkehrsgesellschaft'],
'8007H2' => ['DB', 'DB Regio AG Bayern'],
'850360' => ['BSB', 'Bodensee-Schiffsbetriebe'],
'3270' => ['TN', 'TRENORD'],
'800161' => ['DB', 'DB Regio AG Nordost'],
'800765' => ['DB', 'DB Regio AG Bayern'],
'850035' => ['BOB', 'Berner Oberland-Bahnen'],
'850064' => ['MOB', 'Montreux-Oberland Bernois'],
'80001' => ['S', 'S-Bahn Berlin'],
'800734' => ['DB', 'DB Regio AG Bayern'],
'WL' => ['RB', 'Kreisbahn Mansfelder Land'],
'GARE' => ['RE', 'Go-Ahead Baden-Württemberg GmbH'],
'8015H9' => ['DB', 'DB Regio AG Mitte'],
'NBRB62' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'GAMEX' => ['MEX', 'Go-Ahead Baden-Württemberg GmbH'],
'vuvab' => ['VU', 'Verkehrsgesellschaft mbH Untermain'],
'Y8' => ['BRB', 'Bayerische Regiobahn'],
'vgmb93' => ['WB', 'Westfalenbus'],
'800337' => ['DB', 'DB Regio AG NRW'],
'801539' => ['DB', 'DB Regio AG Mitte'],
'N1' => ['NWB', 'NordWestBahn'],
'OWRB65' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'850023' => ['TPC', 'Transports Publics du Chablais'],
'GARB' => ['RB', 'Go-Ahead Baden-Württemberg GmbH'],
'80' => ['DB', 'DB Fernverkehr AG'],
'NBRB35' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'850081' => ['ASM', 'Aare Seeland mobil'],
'810017' => ['NÖV', 'NÖ Verkehrsorganisations-ges.m.b.H.'],
'KD' => ['KD', 'Köln-Düsseldorfer Deutsche Rheinschifffahrt GmbH'],
'8' => ['S', 'S-Bahn Berlin'],
'80TRI' => ['EC', 'DB/SBB/TI'],
'8006C6' => ['DB', 'DB Regio AG Baden-Württemberg'],
'W9' => ['WBA', 'waldbahn - Die Länderbahn GmbH DLB'],
'800790' => ['DB', 'DB Regio AG Bayern'],
'8003H5' => ['DB', 'DB Regio AG NRW'],
'S6' => ['SWE', 'SWEG Südwestdeutsche Landesverkehrs-GmbH'],
'W2' => ['Dab', 'Daadetalbahn'],
'RW' => ['PRE', 'Pressnitztalbahn'],
'O9' => ['OPB', 'oberpfalzbahn - Die Länderbahn GmbH DLB'],
'800574' => ['DB', 'DB Regio AG Mitte'],
'rbpRMB' => ['DB', 'RMB Rhein-Mosel-Bus'],
'850086' => ['ZB', 'Zentralbahn'],
'A6S34' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'800572' => ['DB', 'DB Regio AG Mitte'],
'800293' => ['DB', 'DB Regio AG Nord'],
'859014' => ['VDB', 'Verein Dampfbahn Bern'],
'54' => ['CD', 'Ceske Drahy'],
'M1' => ['P', 'Museumsbahn'],
'800310' => ['DB', 'DB Regio AG NRW'],
'vrnOEG' => ['RNV', 'Rhein-Neckar-Verkehr GmbH (Oberrheinische Eisenbahn)'],
'R7' => ['HzL', 'Hohenzollerische Landesbahn (SWEG)'],
'B3' => ['P', 'Brohltalbahn'],
'800158' => ['DB', 'DB Regio AG Nordost'],
'82' => ['CFL', 'CFL'],
'800166' => ['DB', 'DB Regio AG Nordost'],
'800767' => ['DB', 'DB Regio AG Bayern'],
'8005MW' => ['DB', 'DB Regio AG Mitte'],
'51PR' => ['PR', 'Polregio'],
'O0' => ['NBE', 'Nordbahn Eisenbahngesellschaft'],
'FLX35' => ['FLX', 'FlixTrain'],
'74' => ['SJ', 'SJ'],
'rbgFMO' => ['FMO', 'Friedrich Müller Omnibusunternehmen GmbH'],
'A0' => ['AKN', 'AKN Eisenbahn GmbH'],
'850042' => ['MVR', 'Montreux-Vevey-Riviera'],
'FLX20' => ['FLX', 'FlixTrain'],
'PB' => ['RB', 'Hanseatische Eisenbahn GmbH'],
'webYUE' => ['RBB', 'Regionalbus Braunschweig GmbH'],
'N4RE' => ['RE', 'cantus Verkehrsgesellschaft'],
'857200' => ['SBB', 'SBB'],
'R4RB35' => ['VIA', 'VIAS Rail GmbH'],
'80SSP' => ['D', 'Sylt Shuttle Plus'],
'8006SH' => ['DB', 'DB Regio AG Baden-Württemberg'],
'78' => ['HZ', 'HZPP'],
'800445' => ['DB', 'DB Regio AG Südost'],
'B6' => ['DB', 'DB Regio AG Baden-Württemberg'],
'850044' => ['TRN', 'Transports Publics Neuchâtelois SA'],
'800156' => ['DB', 'DB Regio AG Nordost'],
'OWBus' => ['OE', 'Ostdeutsche Eisenbahn GmbH'],
'BE' => ['BE', 'Bentheimer Eisenbahn'],
'850074' => ['RA', 'Regionalps'],
'AL' => ['DWE', 'Dessau-Wörlitzer Eisenbahn'],
'850096' => ['WSB', 'Wynental-und Suhrental-Bahn'],
'N4' => ['RB', 'cantus Verkehrsgesellschaft'],
'800352' => ['DB', 'DB Regio AG NRW'],
'800159' => ['DB', 'DB Regio AG Nordost'],
'vvs012' => ['WEG', 'Württembergische Eisenbahn-Gesellschaft mbH'],
'800354' => ['DB', 'DB Regio AG NRW'],
'S3' => ['SWB', 'Stadtwerke Bonn'],
'rbpRPB' => ['RPB', 'Rheinpfalzbus'],
'850072' => ['RhB', 'Rhätische Bahn'],
'N8' => ['P', 'BayernBahn GmbH'],
'A9' => ['ag', 'agilis'],
'850088' => ['RBS', 'Regionalverkehr Bern-Solothurn'],
'8004L1' => ['DB', 'DB Regio AG Südost'],
'webXOS' => ['WEB', 'Weser-Ems-Bus'],
'800523' => ['KHB', 'DB RegioNetz Verkehrs GmbH Kurhessenbahn'],
'8004A9' => ['DB', 'DB Regio AG Südost'],
'8015FR' => ['DB', 'DB Regio AG Mitte'],
'EB' => ['RB', 'Erfurter Bahn GmbH'],
'3189' => ['ARV', 'ARRIVA vlaky'],
'NBRB54' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'M8' => ['BRB', 'Bayerische Regiobahn'],
'800721' => ['DB', 'DB Regio AG Bayern'],
'A6S8' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'K4RE' => ['HLB', 'HLB Hessenbahn GmbH'],
'pbaWR' => ['ÖPO', 'ÖBB-Postbus'],
'K4RB' => ['HLB', 'HLB Hessenbahn GmbH'],
'A6S1' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'NY' => ['MSM', 'MSM Partyzug'],
'M4' => ['VSE', 'Verein Sächsischer Eisenbahnfreunde'],
'51' => ['PKP', 'PKP Intercity'],
'OWRB19' => ['RB', 'Ostdeutsche Eisenbahn GmbH'],
'8003G2' => ['DB', 'DB Regio AG NRW'],
'F7' => ['RB', 'Bodensee-Oberschwaben-Bahn'],
'800151' => ['DB', 'DB Regio AG Nordost'],
'800755' => ['DB', 'DB Regio AG Bayern'],
'H4' => ['RT', 'RegioTram'],
'rbgBRN' => ['BRN', 'Busverkehr Rhein-Neckar'],
'853186' => ['SZR', 'Schiff Eglisau-Tössegg'],
'743051' => ['ST', 'Snälltåget'],
'K4' => ['HLB', 'HLB Hessenbahn GmbH'],
'801512' => ['DB', 'DB Regio AG Mitte'],
'8013D' => ['SOB', 'DB RegioNetz Verkehrs GmbH Südostbayernbahn'],
'51PR-R' => ['PR', 'Polregio'],
'800535' => ['DB', 'DB Regio AG Mitte'],
'850193' => ['URh', 'Untersee und Rhein'],
'3288' => ['GW', 'GW Train Regio'],
'R1' => ['ME', 'metronom'],
'SAB' => ['SAB', 'Schwäbische Alb-Bahn'],
'W3' => ['WFB', 'WestfalenBahn'],
'850082' => ['SOB', 'Schweizerische Südostbahn (sob)'],
'850078' => ['SZU', 'Sihltal-Zürich-Uetliberg-Bahn'],
'H7' => ['HzL', 'Hohenzollerische Landesbahn (SWEG)'],
'800659' => ['DB', 'DB Regio AG Baden-Württemberg'],
'FLX15' => ['FLX', 'FlixTrain'],
'840037' => ['Rnt', 'R-net'],
'857210' => ['SBB', 'SBB'],
'NBRB61' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'MW' => ['MBB', 'Mecklenburgische Bäderbahn Molli'],
'800785' => ['DB', 'DB Regio AG Bayern'],
'A6S5' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'83' => ['TI', 'Trenitalia'],
'A6S71' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'X2' => ['erx', 'erixx'],
'rbpORN' => ['ORN', 'ORN Omnibusverkehr Rhein-Nahe GmbH (Rhein-Nahe-Bus)'],
'NB' => ['RB', 'NEB Niederbarnimer Eisenbahn'],
'A8N' => ['ALX', 'alex - Die Länderbahn GmbH DLB'],
'B2' => ['DB', 'DB Regio AG NRW'],
'A6S41' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'8007H1' => ['DB', 'DB Regio AG Bayern'],
'8003S' => ['DB', 'DB Regio AG NRW'],
'3613' => ['StB', 'Steiermarkbahn und Bus GmbH'],
'850048' => ['MGB', 'Matterhorn Gotthard Bahn (fo)'],
'850195' => ['SBS', 'Schweizerische Bodensee-Schiffahrtsgesellschaft'],
'css002' => ['P', 'Chiemseebahn'],
'55' => ['MAV', 'MAV'],
'850061' => ['TMR', 'Transports de Martigny et Régions (mc)'],
'8004NT' => ['DB', 'DB Regio AG Südost'],
'801518' => ['DB', 'DB Regio AG Mitte'],
'8006A7' => ['WFB', 'DB RegioNetz Verkehrs GmbH Westfrankenbahn'],
'ABIRE' => ['IRE', 'SWEG Bahn Stuttgart GmbH'],
'850066' => ['NSt', 'Nyon-St-Cergue-Morez'],
'vgm093' => ['WB', 'Westfalenbus'],
'RD' => ['VBG', 'vogtlandbahn - Die Länderbahn GmbH DLB'],
'8007D4' => ['DB', 'DB Regio AG Bayern'],
'C8' => ['LEO', 'Chiemgauer Lokalbahn'],
'RSNM' => ['RB', 'Regionalverkehre Start Deutschland GmbH (Start Niedersachsen-Mitte)'],
'V7' => ['SVG', 'SVG Schienenverkehrsgesellschaft Stuttgart'],
'8002B5' => ['DB', 'DB Regio AG Nord'],
'Z9' => ['P', 'Rhön-Zügle'],
'800201' => ['DB', 'DB Regio AG Nord'],
'rbpSWM' => ['DB', 'DB Regio Bus Mitte'],
'8006C4' => ['DB', 'DB Regio AG Baden-Württemberg'],
'800571' => ['DB', 'DB Regio AG Mitte'],
'860087' => ['ARR', 'Arriva Danmark'],
'800348' => ['DB', 'DB Regio AG NRW'],
'LDTLX' => ['TLX', 'trilex-express - Die Länderbahn GmbH DLB'],
'800603' => ['WFB', 'DB RegioNetz Verkehrs GmbH Westfrankenbahn'],
'A6S42' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'D3' => ['RTB', 'Rurtalbahn'],
'800487' => ['DB', 'DB Regio AG Südost'],
'A6' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'800694' => ['DB', 'DB Regio AG Baden-Württemberg'],
'A6S6' => ['AVG', 'Albtal-Verkehrs-Gesellschaft mbH'],
'857LEX' => ['LEX', 'LEX'],
);

sub get_operator {
	my ($id) = @_;
	if (not defined $id) {
		return;
	}
	return $admin_id_to_operator{$id};
}

sub get_operator_abbr {
	my ($id) = @_;
	if (not defined $id) {
		return;
	}
	if (my $op = $admin_id_to_operator{$id}) {
		return $op->[0];
	}
	return;
}

sub get_operator_name {
	my ($id) = @_;
	if (not defined $id) {
		return;
	}
	if (my $op = $admin_id_to_operator{$id}) {
		return $op->[1];
	}
	return;
}

1;
